@@ -50,11 +50,11 @@ parameters, and site parameters
 
 =head1 VERSION
 
-Version 0.205
+Version 0.206
 
 =cut
 
-our $VERSION = '0.205';
+our $VERSION = '0.206';
 
 
 
@@ -268,7 +268,7 @@ sub set {
             %ARGS = (   
                         %ARGS,
                         code => 'CELL_OVERWRITE_META_PARAM',
-                        args => [ $param, $value ],
+                        args => [ $param, ( defined( $value ) ? $value : 'undef' ) ],
                     );
             #$log->debug( "Overwriting \$meta->$param with ->$value<-", cell => 1 );
         } else {
