@@ -54,11 +54,11 @@ App::CELL::Load -- find and load message files and config files
 
 =head1 VERSION
 
-Version 0.205
+Version 0.206
 
 =cut
 
-our $VERSION = '0.205';
+our $VERSION = '0.206';
 
 
 
@@ -121,7 +121,7 @@ our @sitedir = ();
 
 =head2 init
 
-Re-entrant initialization function.
+Idempotent initialization function.
 
 Optionally takes a PARAMHASH. The following arguments are recognized:
 
